@@ -20,7 +20,7 @@ def set_rand_state(RAND_STATE):
     random.seed(RAND_STATE)
     return None
     
-def train_gridsearch_classifier(umap_df,test_size=0.3,num_CV=5,verbosity=0):
+def train_gridsearch_classifier(umap_df,test_size=0.3,num_CV=5,verbose=0):
     UMAP_X = np.stack(umap_df['waveform'].to_numpy().tolist(), axis=0)
     UMAP_y = umap_df['cluster_id'].to_numpy()
     UMAP_X_train, UMAP_X_test, UMAP_y_train, UMAP_y_test = train_test_split(UMAP_X,     UMAP_y, test_size=test_size, random_state=RAND_STATE)
@@ -33,7 +33,7 @@ def train_gridsearch_classifier(umap_df,test_size=0.3,num_CV=5,verbosity=0):
                   "seed": [RAND_STATE]}
     UMAP_grid_search = GridSearchCV(UMAP_model, param_grid=UMAP_param_dist,
                            cv = num_CV,
-                           verbose=10, n_jobs=-1)
+                           verbose=verbose, n_jobs=-1)
     UMAP_grid_search.fit(UMAP_X_train, UMAP_y_train)
     conf_mat = confusion_matrix(UMAP_y_test,UMAP_grid_search.predict(UMAP_X_test))
     return UMAP_grid_search, conf_mat
